capture log close
log using rm3ch3-esttestfit, replace text

//  Ch 3: Estimation and Testing | rm3ch3-esttestfit.do 2014-08-05
//  Regression Models for Categorical Outcomes using Stata, 3rd edition
//  Scott Long & Jeremy Freese

version 13.1
clear all
macro drop _all
program drop _all
set linesize 80
set scheme s2manual

//  ml estimation

use binlfp4, clear
logit lfp k5 k618 agecat wc hc lwg inc
logit lfp k5 k618 age wc lwg
logit lfp k5 k618 age wc lwg if hc == 1
logit lfp k5 k618 age wc lwg if hc == 1, level(90)

//  3.1.5 Variable lists

* factor notation and indicators

drop age3039 age4049 age50plus
tabulate agecat, missing
generate age3039 = (agecat==1) if agecat < .
label var age3039 "Age 30 to 39?"
generate age4049 = (agecat==2) if agecat < .
label var age4049 "Age 40 to 49?"
generate age50plus = (agecat==3) & agecat < .
label var age50plus "Age 50 or older?"
logit lfp k5 k618 age4049 age50plus wc hc lwg inc, nolog
logit lfp k5 k618 i.agecat wc hc lwg inc, nolog
logit lfp k5 k618 ib3.agecat wc hc lwg inc, nolog
logit lfp k5 k618 agecat wc hc lwg inc, nolog
logit lfp c.k5 c.k618 i.agecat i.wc i.hc c.lwg c.inc, nolog

* interactions

generate wcXk5 = wc*k5
logit lfp wc k5 wcXk5 k618 age hc lwg inc, nolog
logit lfp wc k5 wc#c.k5 k618 age hc lwg inc, nolog
logit lfp i.wc c.k5 i.wc#c.k5 k618 age hc lwg inc , nolog
logit lfp i.wc##c.k5 k618 age hc lwg inc, nolog
logit lfp c.age##c.age k5 k618 wc hc lwg inc, nolog
logit lfp k5 k618 c.age##c.age##c.age wc hc lwg inc, nolog
logit lfp i.wc##(c.k5 c.k618 c.age i.hc c.lwg c.inc), nolog
logit lfp i.agecat c.age##c.age, nolog
logit, coeflegend
summarize i.agecat c.inc##c.inc
summarize i.agecat c.inc##c.inc, nofvlabel
logit lfp i.agecat i.wc i.hc k5 k618 lwg inc, nolog
logit lfp i.agecat i.wc i.hc k5 k618 lwg inc, nolog

//  3.1.6 Specifying the estimation sample

use binlfp4-missing, clear
logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog
logit lfp k5 i.agecat i.wc i.hc lwg inc, nolog
mark nomiss
markout nomiss lfp k5 k618 agecat wc hc lwg inc
tab nomiss
logit lfp k5 k618 i.agecat i.wc i.hc lwg inc if nomiss==1, nolog
logit lfp k5 i.agecat i.wc i.hc lwg inc if nomiss==1, nolog

* information about missing values

use gsskidvalue4, clear
egen missing = rowmiss(age anykids black degree female kidvalue othrrace ///
year income91 income)
tab missing
misstable summarize age anykids black degree female kidvalue othrrace ///
year income91 income, all showzero
misstable patterns age anykids black degree female kidvalue othrrace ///
year income91 income, freq
misstable summarize age anykids black degree female kidvalue othrrace ///
year income91 income, gen(m_)
logit m_income female black othrrace age, nolog

* postestimation commands and the estimation sample

logit m_income female black othrrace age i.degree, nolog
gen included = e(sample)
label var included "Cases included in logit on m_income"
tab included

//  3.1.7 Weights and survey data

use svyhrs4, clear
svyset secu [pweight=kwgtr], strata(stratum)

svy: logit arthritis male i.ed3cat age

svyset [pweight=kwgtr]
svy: logit arthritis male ib3.ed3cat age
est store svwt
logit arthritis male ib3.ed3cat age [pweight=kwgtr]
est store nowt

svyset secu
svy: logit arthritis male ib3.ed3cat age
est store svcl
logit arthritis male ib3.ed3cat age, cluster(secu)
est store nocl

svyset secu [pweight=kwgtr]
svy: logit arthritis male ib3.ed3cat age
est store svclwt
logit arthritis male ib3.ed3cat age [pweight=kwgtr], cluster(secu)
est store noclwt

//  3.1.10 Reading the estimation output

use binlfp4, clear
logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog

//  3.1.11 Storing estimation results

use binlfp4, clear
logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog
estimates store logit1

* (advanced) Saving estimates to a file

use binlfp4, clear
logit lfp k5 if wc==1, nolog
estimates save model1, replace
clear all
estimates use model1
estimates replay
estimates describe
use binlfp4, clear
estimates esample: lfp k5 if wc==1
estat summarize

//  3.1.12 Reformatting output with estimates table

use binlfp4, clear
logit lfp k5 i.agecat i.wc, nolog
estimates store logit_model
probit lfp k5 i.agecat i.wc, nolog
estimates store probit_model
estimates table logit_model probit_model, b(%12.3f) t varlabel
ereturn list

//  3.2 Testing

use binlfp4, clear
logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog

* Wald tests

test k5
test k5 k618
test k5 k618 2.agecat 3.agecat 1.wc 1.hc lwg inc
test 2.agecat 3.agecat
testparm i.agecat
test k5=k618
test 2.agecat=3.agecat
test k5=k618
test 1.wc=1.hc, accumulate

* LR tests

logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog
estimates store full
logit lfp i.agecat i.wc i.hc lwg inc, nolog
estimates store nokidvars
lrtest full nokidvars
logit lfp, nolog
lrtest full .

//  3.3 Measures of fit

use binlfp4, clear
logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog
fitstat, ic saving(basemodel)

generate kids = k5 + k618
label var kids "Number of kids 18 or younger"
logit lfp kids i.agecat i.wc i.hc lwg inc, nolog
fitstat, ic using(basemodel)

logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog
estat classification

logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog
fitstat, ic

//  3.4 estat post-estimation commands

use binlfp4, clear
logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog
estat summarize
estat ic
estat vce

log close
exit
